==> vue-image-2.8.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/image/vue";
import { defineComponent, Teleport, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import ImageViewer from "@dftvue2-opentiny/vue-image-viewer";
import imageError from "@dftvue2-opentiny/vue-theme/images/image-error.jpg";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    ImageViewer,
    Teleport
  },
  emits: ["load", "error", "delete"],
  props: [].concat(props, ["src", "fit", "lazy", "scrollContainer", "previewSrcList", "zIndex", "showIndex", "showHover", "previewVisible", "round", "imageSize"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        images: {
          imageError
        }
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["relative inline-block overflow-hidden w-full rounded", {
      "rounded-full": _vm.round
    }],
    style: {
      "width": (!_vm.lazy ? _vm.imageSize : "") + "px",
      "height": (!_vm.lazy ? _vm.imageSize : "") + "px"
    },
    attrs: {
      "data-tag": "tiny-image"
    }
  }, [_vm.state.loading ? _vm._t("placeholder", function() {
    return [_c("div", {
      staticClass: "w-full h-full"
    })];
  }, {
    "dataTag": "tiny-image-loading"
  }) : _vm.state.error ? _vm._t("error", function() {
    return [_c("img", {
      staticClass: "flex justify-center items-center text-sm align-middle text-color-bg-3 bg-no-repeat bg-center",
      attrs: {
        "src": _vm.state.images.imageError,
        "alt": ""
      }
    })];
  }, {
    "dataTag": "tiny-image-error"
  }) : _c("img", _vm._b({
    class: ["align-top w-full h-full rounded cursor-pointer", {
      "relative left-1/2 top-1/2 -translate-y-1/2 -translate-x-1/2 block": _vm.state.getAlignCenter
    }],
    style: _vm.state.getImageStyle,
    attrs: {
      "src": _vm.src
    },
    on: {
      "click": _vm.clickHandler
    }
  }, "img", _vm.$attrs, false)), _c("div", {
    class: ["inline-block w-full h-full hover:bg-color-text-disabled absolute top-0 left-0 cursor-pointer", _vm.showHover ? "block" : "hidden"],
    attrs: {
      "data-tag": "tiny-image-showhover"
    }
  }), _c("teleport", {
    attrs: {
      "to": "body"
    }
  }, [_vm.state.getPreview && _vm.state.showViewer ? _c("image-viewer", {
    attrs: {
      "z-index": _vm.zIndex,
      "on-close": _vm.closeViewer,
      "url-list": _vm.previewSrcList,
      "show-index": _vm.showIndex
    },
    on: {
      "delete": _vm.deleteHander
    }
  }) : _vm._e()], 1)], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-image-2.25.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/image/vue';
import { defineComponent, Teleport, props, setup } from '@opentinyvue/vue-common';
import ImageViewer from '@opentinyvue/vue-image-viewer';
import imageError from '@opentinyvue/vue-theme/images/image-error.jpg';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    ImageViewer,
    Teleport
  },
  emits: ["load", "error", "delete", "change-index"],
  props: [].concat(props, ["src", "fit", "lazy", "scrollContainer", "previewSrcList", "zIndex", "showIndex", "showHover", "previewVisible", "round", "imageSize", "keepStyle", "appendToBody"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        images: {
          imageError
        }
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["relative inline-block overflow-hidden w-full rounded", {
      "rounded-full": _vm.round
    }],
    style: {
      "width": (!_vm.lazy ? _vm.imageSize : "") + "px",
      "height": (!_vm.lazy ? _vm.imageSize : "") + "px"
    },
    attrs: {
      "data-tag": "tiny-image"
    }
  }, [_vm.state.loading ? _vm._t("placeholder", function() {
    return [_c("div", {
      staticClass: "w-full h-full"
    })];
  }, {
    "dataTag": "tiny-image-loading"
  }) : _vm.state.error ? _vm._t("error", function() {
    return [_c("img", {
      staticClass: "flex justify-center items-center text-sm align-middle text-color-bg-3 bg-no-repeat bg-center",
      attrs: {
        "src": _vm.state.images.imageError,
        "alt": ""
      }
    })];
  }, {
    "dataTag": "tiny-image-error"
  }) : _c("img", _vm._b({
    class: ["align-top w-full h-full rounded cursor-pointer", {
      "relative left-1/2 top-1/2 -translate-y-1/2 -translate-x-1/2 block": _vm.state.getAlignCenter
    }],
    style: _vm.state.getImageStyle,
    attrs: {
      "src": _vm.state.src
    },
    on: {
      "click": _vm.clickHandler
    }
  }, "img", _vm.$attrs, false)), _c("div", {
    class: ["inline-block w-full h-full hover:bg-color-text-disabled absolute top-0 left-0 cursor-pointer", _vm.showHover ? "block" : "hidden"],
    attrs: {
      "data-tag": "tiny-image-showhover"
    }
  }), _c("teleport", {
    attrs: {
      "disabled": !_vm.appendToBody,
      "to": "body"
    }
  }, [_vm.state.getPreview && _vm.state.showViewer ? _c("image-viewer", {
    attrs: {
      "z-index": _vm.zIndex,
      "on-switch": _vm.handleSwitch,
      "on-close": _vm.closeViewer,
      "url-list": _vm.previewSrcList,
      "show-index": _vm.showIndex,
      "keep-style": _vm.keepStyle
    },
    on: {
      "delete": _vm.deleteHander
    },
    scopedSlots: _vm._u([{
      key: "count",
      fn: function fn(slotScoped) {
        return [_vm._t("count", null, {
          "index": slotScoped.index
        })];
      }
    }], null, true)
  }) : _vm._e()], 1)], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
